
System Monitoring Over Syslog - Client Module
=============================================

A python client to format `Metrics`_ and send it to syslog.

Metrics
-------

A key value pair that represent measurement or monitored status.
eg. fanspeed at 78

